pub fn build_graph(model: &ModelProto) -> Result<BuiltGraph, LoaderError>Expand description
Build the IR graph (nodes, values, symbols, opsets) from a ModelProto.
Weights and shape inference are applied by later pipeline stages.
pub fn build_graph(model: &ModelProto) -> Result<BuiltGraph, LoaderError>Build the IR graph (nodes, values, symbols, opsets) from a ModelProto.
Weights and shape inference are applied by later pipeline stages.