pub fn referenced_weight_bytes(model: &ModelProto) -> ReferencedWeightBytesExpand description
Sum the initializer payload ReferencedWeightBytes a model’s graph
references. See that type for why file size is not a substitute.
pub fn referenced_weight_bytes(model: &ModelProto) -> ReferencedWeightBytesSum the initializer payload ReferencedWeightBytes a model’s graph
references. See that type for why file size is not a substitute.